elephant\.test\.make\_spike\_extraction\_test\_data module
==========================================================

.. automodule:: elephant.test.make_spike_extraction_test_data
    :members:
    :undoc-members:
    :show-inheritance:
